{arn} {region} {runtime}

ARN | {arn}
Name | {name}
Description | {description}
Region | {region}
Runtime | {runtime}
Handler | {handler}
Role | {role}
KMS | {kms}
Layers ({layers_count}) | {layers}
Triggers ({triggers_count}) | {triggers}
Resources ({resources_count}) | {resources}
Security ({security_count}) |
Level | Text | Where
{security}
Function policy |
    {policy}
Execution role policy |
    {role_policy}
KMS policies |
    {kms_policies}